@@ -129,7 +129,7 @@ class Exceptions:
 
 class MemoryDBClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/memorydb.html#MemoryDB.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/memorydb.html#MemoryDB.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html)
     """
 
@@ -142,12 +142,12 @@ class MemoryDBClient(BaseClient):
         """
 
     def batch_update_cluster(
-        self, *, ClusterNames: Sequence[str], ServiceUpdate: "ServiceUpdateRequestTypeDef" = None
+        self, *, ClusterNames: Sequence[str], ServiceUpdate: "ServiceUpdateRequestTypeDef" = ...
     ) -> BatchUpdateClusterResponseTypeDef:
         """
         Apply the service update to a list of clusters supplied.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/memorydb.html#MemoryDB.Client.batch_update_cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/memorydb.html#MemoryDB.Client.batch_update_cluster)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#batch_update_cluster)
         """
 
@@ -155,7 +155,7 @@ class MemoryDBClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/memorydb.html#MemoryDB.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/memorydb.html#MemoryDB.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#can_paginate)
         """
 
@@ -164,24 +164,24 @@ class MemoryDBClient(BaseClient):
         *,
         SourceSnapshotName: str,
         TargetSnapshotName: str,
-        TargetBucket: str = None,
-        KmsKeyId: str = None,
-        Tags: Sequence["TagTypeDef"] = None
+        TargetBucket: str = ...,
+        KmsKeyId: str = ...,
+        Tags: Sequence["TagTypeDef"] = ...
     ) -> CopySnapshotResponseTypeDef:
         """
         Makes a copy of an existing snapshot.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/memorydb.html#MemoryDB.Client.copy_snapshot)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/memorydb.html#MemoryDB.Client.copy_snapshot)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#copy_snapshot)
         """
 
     def create_acl(
-        self, *, ACLName: str, UserNames: Sequence[str] = None, Tags: Sequence["TagTypeDef"] = None
+        self, *, ACLName: str, UserNames: Sequence[str] = ..., Tags: Sequence["TagTypeDef"] = ...
     ) -> CreateACLResponseTypeDef:
         """
         Creates an Access Control List.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/memorydb.html#MemoryDB.Client.create_acl)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/memorydb.html#MemoryDB.Client.create_acl)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#create_acl)
         """
 
@@ -191,29 +191,29 @@ class MemoryDBClient(BaseClient):
         ClusterName: str,
         NodeType: str,
         ACLName: str,
-        ParameterGroupName: str = None,
-        Description: str = None,
-        NumShards: int = None,
-        NumReplicasPerShard: int = None,
-        SubnetGroupName: str = None,
-        SecurityGroupIds: Sequence[str] = None,
-        MaintenanceWindow: str = None,
-        Port: int = None,
-        SnsTopicArn: str = None,
-        TLSEnabled: bool = None,
-        KmsKeyId: str = None,
-        SnapshotArns: Sequence[str] = None,
-        SnapshotName: str = None,
-        SnapshotRetentionLimit: int = None,
-        Tags: Sequence["TagTypeDef"] = None,
-        SnapshotWindow: str = None,
-        EngineVersion: str = None,
-        AutoMinorVersionUpgrade: bool = None
+        ParameterGroupName: str = ...,
+        Description: str = ...,
+        NumShards: int = ...,
+        NumReplicasPerShard: int = ...,
+        SubnetGroupName: str = ...,
+        SecurityGroupIds: Sequence[str] = ...,
+        MaintenanceWindow: str = ...,
+        Port: int = ...,
+        SnsTopicArn: str = ...,
+        TLSEnabled: bool = ...,
+        KmsKeyId: str = ...,
+        SnapshotArns: Sequence[str] = ...,
+        SnapshotName: str = ...,
+        SnapshotRetentionLimit: int = ...,
+        Tags: Sequence["TagTypeDef"] = ...,
+        SnapshotWindow: str = ...,
+        EngineVersion: str = ...,
+        AutoMinorVersionUpgrade: bool = ...
     ) -> CreateClusterResponseTypeDef:
         """
         Creates a cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/memorydb.html#MemoryDB.Client.create_cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/memorydb.html#MemoryDB.Client.create_cluster)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#create_cluster)
         """
 
@@ -222,13 +222,13 @@ class MemoryDBClient(BaseClient):
         *,
         ParameterGroupName: str,
         Family: str,
-        Description: str = None,
-        Tags: Sequence["TagTypeDef"] = None
+        Description: str = ...,
+        Tags: Sequence["TagTypeDef"] = ...
     ) -> CreateParameterGroupResponseTypeDef:
         """
         Creates a new MemoryDB parameter group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/memorydb.html#MemoryDB.Client.create_parameter_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/memorydb.html#MemoryDB.Client.create_parameter_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#create_parameter_group)
         """
 
@@ -237,13 +237,13 @@ class MemoryDBClient(BaseClient):
         *,
         ClusterName: str,
         SnapshotName: str,
-        KmsKeyId: str = None,
-        Tags: Sequence["TagTypeDef"] = None
+        KmsKeyId: str = ...,
+        Tags: Sequence["TagTypeDef"] = ...
     ) -> CreateSnapshotResponseTypeDef:
         """
         Creates a copy of an entire cluster at a specific moment in time.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/memorydb.html#MemoryDB.Client.create_snapshot)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/memorydb.html#MemoryDB.Client.create_snapshot)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#create_snapshot)
         """
 
@@ -252,13 +252,13 @@ class MemoryDBClient(BaseClient):
         *,
         SubnetGroupName: str,
         SubnetIds: Sequence[str],
-        Description: str = None,
-        Tags: Sequence["TagTypeDef"] = None
+        Description: str = ...,
+        Tags: Sequence["TagTypeDef"] = ...
     ) -> CreateSubnetGroupResponseTypeDef:
         """
         Creates a subnet group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/memorydb.html#MemoryDB.Client.create_subnet_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/memorydb.html#MemoryDB.Client.create_subnet_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#create_subnet_group)
         """
 
@@ -268,12 +268,12 @@ class MemoryDBClient(BaseClient):
         UserName: str,
         AuthenticationMode: "AuthenticationModeTypeDef",
         AccessString: str,
-        Tags: Sequence["TagTypeDef"] = None
+        Tags: Sequence["TagTypeDef"] = ...
     ) -> CreateUserResponseTypeDef:
         """
         Creates a MemoryDB user.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/memorydb.html#MemoryDB.Client.create_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/memorydb.html#MemoryDB.Client.create_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#create_user)
         """
 
@@ -281,17 +281,17 @@ class MemoryDBClient(BaseClient):
         """
         Deletes an Access Control List.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/memorydb.html#MemoryDB.Client.delete_acl)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/memorydb.html#MemoryDB.Client.delete_acl)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#delete_acl)
         """
 
     def delete_cluster(
-        self, *, ClusterName: str, FinalSnapshotName: str = None
+        self, *, ClusterName: str, FinalSnapshotName: str = ...
     ) -> DeleteClusterResponseTypeDef:
         """
         Deletes a cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/memorydb.html#MemoryDB.Client.delete_cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/memorydb.html#MemoryDB.Client.delete_cluster)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#delete_cluster)
         """
 
@@ -301,7 +301,7 @@ class MemoryDBClient(BaseClient):
         """
         Deletes the specified parameter group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/memorydb.html#MemoryDB.Client.delete_parameter_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/memorydb.html#MemoryDB.Client.delete_parameter_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#delete_parameter_group)
         """
 
@@ -309,7 +309,7 @@ class MemoryDBClient(BaseClient):
         """
         Deletes an existing snapshot.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/memorydb.html#MemoryDB.Client.delete_snapshot)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/memorydb.html#MemoryDB.Client.delete_snapshot)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#delete_snapshot)
         """
 
@@ -317,7 +317,7 @@ class MemoryDBClient(BaseClient):
         """
         Deletes a subnet group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/memorydb.html#MemoryDB.Client.delete_subnet_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/memorydb.html#MemoryDB.Client.delete_subnet_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#delete_subnet_group)
         """
 
@@ -325,12 +325,12 @@ class MemoryDBClient(BaseClient):
         """
         Deletes a user.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/memorydb.html#MemoryDB.Client.delete_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/memorydb.html#MemoryDB.Client.delete_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#delete_user)
         """
 
     def describe_acls(
-        self, *, ACLName: str = None, MaxResults: int = None, NextToken: str = None
+        self, *, ACLName: str = ..., MaxResults: int = ..., NextToken: str = ...
     ) -> DescribeACLsResponseTypeDef:
         """
         Returns a list of ACLs See also: `AWS API Documentation
@@ -338,88 +338,88 @@ class MemoryDBClient(BaseClient):
         **Request Syntax** response = client.describe_acls( ACLName='string',
         MaxResults=123, NextToken='string' ).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/memorydb.html#MemoryDB.Client.describe_acls)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/memorydb.html#MemoryDB.Client.describe_acls)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#describe_acls)
         """
 
     def describe_clusters(
         self,
         *,
-        ClusterName: str = None,
-        MaxResults: int = None,
-        NextToken: str = None,
-        ShowShardDetails: bool = None
+        ClusterName: str = ...,
+        MaxResults: int = ...,
+        NextToken: str = ...,
+        ShowShardDetails: bool = ...
     ) -> DescribeClustersResponseTypeDef:
         """
         Returns information about all provisioned clusters if no cluster identifier is
         specified, or about a specific cluster if a cluster name is supplied.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/memorydb.html#MemoryDB.Client.describe_clusters)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/memorydb.html#MemoryDB.Client.describe_clusters)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#describe_clusters)
         """
 
     def describe_engine_versions(
         self,
         *,
-        EngineVersion: str = None,
-        ParameterGroupFamily: str = None,
-        MaxResults: int = None,
-        NextToken: str = None,
-        DefaultOnly: bool = None
+        EngineVersion: str = ...,
+        ParameterGroupFamily: str = ...,
+        MaxResults: int = ...,
+        NextToken: str = ...,
+        DefaultOnly: bool = ...
     ) -> DescribeEngineVersionsResponseTypeDef:
         """
         Returns a list of the available Redis engine versions.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/memorydb.html#MemoryDB.Client.describe_engine_versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/memorydb.html#MemoryDB.Client.describe_engine_versions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#describe_engine_versions)
         """
 
     def describe_events(
         self,
         *,
-        SourceName: str = None,
-        SourceType: SourceTypeType = None,
-        StartTime: Union[datetime, str] = None,
-        EndTime: Union[datetime, str] = None,
-        Duration: int = None,
-        MaxResults: int = None,
-        NextToken: str = None
+        SourceName: str = ...,
+        SourceType: SourceTypeType = ...,
+        StartTime: Union[datetime, str] = ...,
+        EndTime: Union[datetime, str] = ...,
+        Duration: int = ...,
+        MaxResults: int = ...,
+        NextToken: str = ...
     ) -> DescribeEventsResponseTypeDef:
         """
         Returns events related to clusters, security groups, and parameter groups.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/memorydb.html#MemoryDB.Client.describe_events)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/memorydb.html#MemoryDB.Client.describe_events)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#describe_events)
         """
 
     def describe_parameter_groups(
-        self, *, ParameterGroupName: str = None, MaxResults: int = None, NextToken: str = None
+        self, *, ParameterGroupName: str = ..., MaxResults: int = ..., NextToken: str = ...
     ) -> DescribeParameterGroupsResponseTypeDef:
         """
         Returns a list of parameter group descriptions.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/memorydb.html#MemoryDB.Client.describe_parameter_groups)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/memorydb.html#MemoryDB.Client.describe_parameter_groups)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#describe_parameter_groups)
         """
 
     def describe_parameters(
-        self, *, ParameterGroupName: str, MaxResults: int = None, NextToken: str = None
+        self, *, ParameterGroupName: str, MaxResults: int = ..., NextToken: str = ...
     ) -> DescribeParametersResponseTypeDef:
         """
         Returns the detailed parameter list for a particular parameter group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/memorydb.html#MemoryDB.Client.describe_parameters)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/memorydb.html#MemoryDB.Client.describe_parameters)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#describe_parameters)
         """
 
     def describe_service_updates(
         self,
         *,
-        ServiceUpdateName: str = None,
-        ClusterNames: Sequence[str] = None,
-        Status: Sequence[ServiceUpdateStatusType] = None,
-        MaxResults: int = None,
-        NextToken: str = None
+        ServiceUpdateName: str = ...,
+        ClusterNames: Sequence[str] = ...,
+        Status: Sequence[ServiceUpdateStatusType] = ...,
+        MaxResults: int = ...,
+        NextToken: str = ...
     ) -> DescribeServiceUpdatesResponseTypeDef:
         """
         Returns details of the service updates See also: `AWS API Documentation <https:/
@@ -427,49 +427,49 @@ class MemoryDBClient(BaseClient):
         **Request Syntax** response = client.describe_service_updates(
         ServiceUpdateName='string', ClusterNames=[ ...
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/memorydb.html#MemoryDB.Client.describe_service_updates)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/memorydb.html#MemoryDB.Client.describe_service_updates)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#describe_service_updates)
         """
 
     def describe_snapshots(
         self,
         *,
-        ClusterName: str = None,
-        SnapshotName: str = None,
-        Source: str = None,
-        NextToken: str = None,
-        MaxResults: int = None,
-        ShowDetail: bool = None
+        ClusterName: str = ...,
+        SnapshotName: str = ...,
+        Source: str = ...,
+        NextToken: str = ...,
+        MaxResults: int = ...,
+        ShowDetail: bool = ...
     ) -> DescribeSnapshotsResponseTypeDef:
         """
         Returns information about cluster snapshots.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/memorydb.html#MemoryDB.Client.describe_snapshots)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/memorydb.html#MemoryDB.Client.describe_snapshots)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#describe_snapshots)
         """
 
     def describe_subnet_groups(
-        self, *, SubnetGroupName: str = None, MaxResults: int = None, NextToken: str = None
+        self, *, SubnetGroupName: str = ..., MaxResults: int = ..., NextToken: str = ...
     ) -> DescribeSubnetGroupsResponseTypeDef:
         """
         Returns a list of subnet group descriptions.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/memorydb.html#MemoryDB.Client.describe_subnet_groups)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/memorydb.html#MemoryDB.Client.describe_subnet_groups)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#describe_subnet_groups)
         """
 
     def describe_users(
         self,
         *,
-        UserName: str = None,
-        Filters: Sequence["FilterTypeDef"] = None,
-        MaxResults: int = None,
-        NextToken: str = None
+        UserName: str = ...,
+        Filters: Sequence["FilterTypeDef"] = ...,
+        MaxResults: int = ...,
+        NextToken: str = ...
     ) -> DescribeUsersResponseTypeDef:
         """
         Returns a list of users.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/memorydb.html#MemoryDB.Client.describe_users)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/memorydb.html#MemoryDB.Client.describe_users)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#describe_users)
         """
 
@@ -480,21 +480,21 @@ class MemoryDBClient(BaseClient):
         **Request Syntax** response = client.failover_shard( ClusterName='string',
         ShardName='string' ).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/memorydb.html#MemoryDB.Client.failover_shard)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/memorydb.html#MemoryDB.Client.failover_shard)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#failover_shard)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Mapping[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/memorydb.html#MemoryDB.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/memorydb.html#MemoryDB.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#generate_presigned_url)
         """
 
@@ -505,7 +505,7 @@ class MemoryDBClient(BaseClient):
         Lists all available node types that you can scale to from your cluster's current
         node type.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/memorydb.html#MemoryDB.Client.list_allowed_node_type_updates)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/memorydb.html#MemoryDB.Client.list_allowed_node_type_updates)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#list_allowed_node_type_updates)
         """
 
@@ -513,7 +513,7 @@ class MemoryDBClient(BaseClient):
         """
         Lists all tags currently on a named resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/memorydb.html#MemoryDB.Client.list_tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/memorydb.html#MemoryDB.Client.list_tags)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#list_tags)
         """
 
@@ -521,14 +521,14 @@ class MemoryDBClient(BaseClient):
         self,
         *,
         ParameterGroupName: str,
-        AllParameters: bool = None,
-        ParameterNames: Sequence[str] = None
+        AllParameters: bool = ...,
+        ParameterNames: Sequence[str] = ...
     ) -> ResetParameterGroupResponseTypeDef:
         """
         Modifies the parameters of a parameter group to the engine or system default
         value.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/memorydb.html#MemoryDB.Client.reset_parameter_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/memorydb.html#MemoryDB.Client.reset_parameter_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#reset_parameter_group)
         """
 
@@ -538,7 +538,7 @@ class MemoryDBClient(BaseClient):
         """
         A tag is a key-value pair where the key and value are case-sensitive.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/memorydb.html#MemoryDB.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/memorydb.html#MemoryDB.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#tag_resource)
         """
 
@@ -551,7 +551,7 @@ class MemoryDBClient(BaseClient):
         **Request Syntax** response = client.untag_resource( ResourceArn='string',
         TagKeys=[ 'string', ] ...
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/memorydb.html#MemoryDB.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/memorydb.html#MemoryDB.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#untag_resource)
         """
 
@@ -559,13 +559,13 @@ class MemoryDBClient(BaseClient):
         self,
         *,
         ACLName: str,
-        UserNamesToAdd: Sequence[str] = None,
-        UserNamesToRemove: Sequence[str] = None
+        UserNamesToAdd: Sequence[str] = ...,
+        UserNamesToRemove: Sequence[str] = ...
     ) -> UpdateACLResponseTypeDef:
         """
         Changes the list of users that belong to the Access Control List.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/memorydb.html#MemoryDB.Client.update_acl)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/memorydb.html#MemoryDB.Client.update_acl)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#update_acl)
         """
 
@@ -573,24 +573,24 @@ class MemoryDBClient(BaseClient):
         self,
         *,
         ClusterName: str,
-        Description: str = None,
-        SecurityGroupIds: Sequence[str] = None,
-        MaintenanceWindow: str = None,
-        SnsTopicArn: str = None,
-        SnsTopicStatus: str = None,
-        ParameterGroupName: str = None,
-        SnapshotWindow: str = None,
-        SnapshotRetentionLimit: int = None,
-        NodeType: str = None,
-        EngineVersion: str = None,
-        ReplicaConfiguration: "ReplicaConfigurationRequestTypeDef" = None,
-        ShardConfiguration: "ShardConfigurationRequestTypeDef" = None,
-        ACLName: str = None
+        Description: str = ...,
+        SecurityGroupIds: Sequence[str] = ...,
+        MaintenanceWindow: str = ...,
+        SnsTopicArn: str = ...,
+        SnsTopicStatus: str = ...,
+        ParameterGroupName: str = ...,
+        SnapshotWindow: str = ...,
+        SnapshotRetentionLimit: int = ...,
+        NodeType: str = ...,
+        EngineVersion: str = ...,
+        ReplicaConfiguration: "ReplicaConfigurationRequestTypeDef" = ...,
+        ShardConfiguration: "ShardConfigurationRequestTypeDef" = ...,
+        ACLName: str = ...
     ) -> UpdateClusterResponseTypeDef:
         """
         Modifies the settings for a cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/memorydb.html#MemoryDB.Client.update_cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/memorydb.html#MemoryDB.Client.update_cluster)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#update_cluster)
         """
 
@@ -600,17 +600,17 @@ class MemoryDBClient(BaseClient):
         """
         Updates the parameters of a parameter group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/memorydb.html#MemoryDB.Client.update_parameter_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/memorydb.html#MemoryDB.Client.update_parameter_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#update_parameter_group)
         """
 
     def update_subnet_group(
-        self, *, SubnetGroupName: str, Description: str = None, SubnetIds: Sequence[str] = None
+        self, *, SubnetGroupName: str, Description: str = ..., SubnetIds: Sequence[str] = ...
     ) -> UpdateSubnetGroupResponseTypeDef:
         """
         Updates a subnet group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/memorydb.html#MemoryDB.Client.update_subnet_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/memorydb.html#MemoryDB.Client.update_subnet_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#update_subnet_group)
         """
 
@@ -618,12 +618,12 @@ class MemoryDBClient(BaseClient):
         self,
         *,
         UserName: str,
-        AuthenticationMode: "AuthenticationModeTypeDef" = None,
-        AccessString: str = None
+        AuthenticationMode: "AuthenticationModeTypeDef" = ...,
+        AccessString: str = ...
     ) -> UpdateUserResponseTypeDef:
         """
         Changes user password(s) and/or access string.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/memorydb.html#MemoryDB.Client.update_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/memorydb.html#MemoryDB.Client.update_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#update_user)
         """
